Struct metered_channel::oneshot::OutputWithMeasurements [−][src]
pub struct OutputWithMeasurements<T> { /* fields omitted */ }Expand description
A wrapping type for the actual type T that is sent with the
oneshot yet allow to attach Measurements to it.
Implements AsRef besides others for easier access to the inner,
wrapped type.
Implementations